      <tr>
        <td align="right" valign="top" width="30%">
          <b>
            <font color="grey">{{ title }}</font>
          </b>
        </td>
        <td align="left" valign="top" width="70%">
          <font>{{ value }}</font>
        </td>
      </tr>
